#
# argument is the prefix such as supermuc
#
#
import sys
import os
import pylab

from helpers import *




Dimensions = [ 2, 3 ]
DTs        = [ 0.01, 0.001, 0.0001 ]
PPCs       = [ 10, 100, 1000 ]
Particles  = [ 1000000, 10000000 ]




def getFilename( dim, variant, particles, ppc, dt, nodes ):
  return sys.argv[1] + "_" + str(particles) + "_" + str(ppc) + "_" + str(dt) + "_DDim" + str(dim) + "_" + variant + "_" + str(nodes) + ".out"
   
   
Iterations = 10
NCols      = 2
Alpha      = 0.3


def plotData(particles,ppc,dt,dim,Nodes):
    Colours = [ 
      "#ff0000", "#bb0000", "#880000",
      "#00ff00", "#00bb00", "#008800",
      "#0000ff", "#0000bb", "#000088",
      "#aabbaa"
    ]
    
    Variants   = [ "pit", "pidt", "rapidt", "sfc-cuts-forward", "sfc-cuts-backward", "sfc-cuts-drop", "sieve-forward", "sieve-backward", "sieve-drop", "md" ]
    BarWidth   = 1.0/(len(Variants)+2)
    
    pylab.clf()
    pylab.xlabel('cores')
    pylab.title( toString(sys.argv[1]) + ", d=" + str(dim) )
    #pylab.ylabel('time per particle [t]=s')
    pylab.ylabel('#particles/s')

    symbolCounter=0
    for variant in Variants:
      xData = []
      yData = []
      nodeCounter  = 0
      for nodes in Nodes:
        inputFilename = getFilename( dim, variant, particles, ppc, dt, nodes )
        print "read " + inputFilename
        runtime       = getRuntime( inputFilename, False );
        xData.append( nodeCounter+(symbolCounter+1)*BarWidth )
        if (runtime>0.0):
          #yData.append( runtime/particles/Iterations )
          yData.append( (particles*Iterations)/runtime )
        else:
          yData.append( 0.0 )
        nodeCounter = nodeCounter+1

      try:
        (xData,yData) = compactData(xData,yData)
        pylab.bar(xData, yData, BarWidth, color=Colours[symbolCounter], label=variant )
      except:
        pass
      symbolCounter = symbolCounter+1

    xData = [a+0.4 for a in range(0,len(Nodes)) ]    
    yData = [a*16 for a in Nodes]
    Delta = len(Nodes)/4
    pylab.xticks( xData[0::Delta], yData[0::Delta] )


def plotReducedData(particles,ppc,dt,dim,Nodes):
    Colours = [ 
      "#ff0000", "#bb0000", "#880000",
      "#00ff00", 
      "#0000ff", "#000088",
      "#aabbaa"
    ]
    

    def mapLabel( variant ):
      if variant=="sfc-cuts-forward":
        return "sfc-cuts"
      if variant=="sieve-forward":
        return "sieve & sort" 
      if variant=="sieve-drop":
        return "sieve & drop" 
      if variant=="md":
        return "linked cell"
      return variant
      
      
    Variants   = [ "pit", "pidt", "rapidt", "sfc-cuts-forward", "sieve-forward", "sieve-drop", "md" ]
    BarWidth   = 1.0/(len(Variants)+2)

    pylab.clf()
    pylab.xlabel('cores')
    pylab.title( toString(sys.argv[1]) + ", d=" + str(dim) )
    #pylab.ylabel('time per particle [t]=s')
    pylab.ylabel('#particles/s')
    pylab.ylim( [ 1e3, 1e8 ] )

    symbolCounter=0
    for variant in Variants:
      xData = []
      yData = []
      nodeCounter  = 0
      for nodes in Nodes:
        inputFilename = getFilename( dim, variant, particles, ppc, dt, nodes )
        print "read " + inputFilename
        runtime       = getRuntime( inputFilename, False );
        xData.append( nodeCounter+(symbolCounter+1)*BarWidth )
        if (runtime>0.0):
          #yData.append( runtime/particles/Iterations )
          yData.append( (particles*Iterations)/runtime )
        else:
          yData.append( 0.0 )
        nodeCounter = nodeCounter+1

      try:
        (xData,yData) = compactData(xData,yData)
        pylab.bar(xData, yData, BarWidth, color=Colours[symbolCounter], label=mapLabel(variant) )
      except:
        pass
      symbolCounter = symbolCounter+1

    xData = [a+0.4 for a in range(0,len(Nodes)) ]    
    yData = [a*16 for a in Nodes]
    Delta = len(Nodes)/4
    pylab.xticks( xData[0::Delta], yData[0::Delta] )


    
    
def writeFiles(outputFilename):
    outputFilename = outputFilename.replace(".","_")

    pylab.grid(False)
    pylab.rcParams.update({'font.size': 18})

    try:
        pylab.legend(loc='upper left',framealpha=0.5,ncol=NCols)
    except:
      #l = pylab.legend(prop={'size':9})
      #l.get_frame().set_alpha(Alpha)
      pass

    pylab.savefig( outputFilename + ".png" )
    pylab.savefig( outputFilename + ".pdf" )
    summaryHTMLFile.write( "<img src=\"" +  outputFilename + ".png\" />" ) 

    try:
      pylab.legend().set_visible(False)

      pylab.savefig( outputFilename + "-no-legend.png" )
      pylab.savefig( outputFilename + "-no-legend.pdf" )
      summaryHTMLFile.write( "<img src=\"" +  outputFilename + "-no-legend.png\" />" ) 

      pylab.legend().set_visible(True)
      try:
        pylab.legend(loc='upper left',framealpha=0.5,ncol=NCols)
      except:
        l = pylab.legend(prop={'size':9})
        l.get_frame().set_alpha(Alpha)
      pylab.yscale( "log" )
      outputFilename = outputFilename + "-log"

      pylab.savefig( outputFilename + ".png" )
      pylab.savefig( outputFilename + ".pdf" )
      summaryHTMLFile.write( "<img src=\"" +  outputFilename + ".png\" />" ) 

      pylab.legend().set_visible(False)

      pylab.savefig( outputFilename + "-no-legend.png" )
      pylab.savefig( outputFilename + "-no-legend.pdf" )
      summaryHTMLFile.write( "<img src=\"" +  outputFilename + "-no-legend.png\" />" ) 
    except:
      pass
    summaryHTMLFile.write( "<br/><br/><br/><br/>" ) 
      
    

def plotAllResults(particles,ppc,dt,dim):
    summaryHTMLFile.write( "<h3>#particles=" + "%.1e" % particles + ",ppc=" + str(ppc) + ",dt=" + str(dt) + "</h3>" ) 

    Nodes      = [ 1, 2, 4, 6 ]
    outputFilename = "result_" + str(dim) + "_" + str(particles) + "_" + str(ppc) + "_" + str(dt) + "-1-6"
    plotData(particles,ppc,dt,dim,Nodes)
    writeFiles(outputFilename);
    

    Nodes      = [ 1, 2, 4, 6, 8, 12, 16 ]
    outputFilename = "result_" + str(dim) + "_" + str(particles) + "_" + str(ppc) + "_" + str(dt) + "-1-16"
    plotData(particles,ppc,dt,dim,Nodes)
    writeFiles(outputFilename);
    

    Nodes      = [ 4, 6, 8, 12, 16 ]
    outputFilename = "result_" + str(dim) + "_" + str(particles) + "_" + str(ppc) + "_" + str(dt) + "-4-16"
    plotData(particles,ppc,dt,dim,Nodes)
    writeFiles(outputFilename);
    

    Nodes      = [ 1, 2, 4, 6, 8, 12, 16, 24, 32, 48, 64 ]
    outputFilename = "result_" + str(dim) + "_" + str(particles) + "_" + str(ppc) + "_" + str(dt) + "-1-64"
    plotData(particles,ppc,dt,dim,Nodes)
    writeFiles(outputFilename);


    Nodes      = [ 1, 2, 4, 6 ]
    outputFilename = "result_reduced-data_" + str(dim) + "_" + str(particles) + "_" + str(ppc) + "_" + str(dt) + "-1-6"
    plotReducedData(particles,ppc,dt,dim,Nodes)
    writeFiles(outputFilename);


    Nodes      = [ 1, 2, 4, 6, 8 ]
    outputFilename = "result_reduced-data_" + str(dim) + "_" + str(particles) + "_" + str(ppc) + "_" + str(dt) + "-1-8"
    plotReducedData(particles,ppc,dt,dim,Nodes)
    writeFiles(outputFilename);


    Nodes      = [ 1, 2, 4, 6, 8, 12 ]
    outputFilename = "result_reduced-data_" + str(dim) + "_" + str(particles) + "_" + str(ppc) + "_" + str(dt) + "-1-12"
    plotReducedData(particles,ppc,dt,dim,Nodes)
    writeFiles(outputFilename);
    

    Nodes      = [ 1, 2, 4, 6, 8, 12, 16 ]
    outputFilename = "result_reduced-data_" + str(dim) + "_" + str(particles) + "_" + str(ppc) + "_" + str(dt) + "-1-16"
    plotReducedData(particles,ppc,dt,dim,Nodes)
    writeFiles(outputFilename);
    

    Nodes      = [ 4, 6, 8, 12, 16 ]
    outputFilename = "result_reduced-data_" + str(dim) + "_" + str(particles) + "_" + str(ppc) + "_" + str(dt) + "-4-16"
    plotReducedData(particles,ppc,dt,dim,Nodes)
    writeFiles(outputFilename);
    

    Nodes      = [ 1, 2, 4, 6, 8, 12, 16, 24, 32, 48, 64 ]
    outputFilename = "result_reduced-data_" + str(dim) + "_" + str(particles) + "_" + str(ppc) + "_" + str(dt) + "-1-64"
    plotReducedData(particles,ppc,dt,dim,Nodes)
    writeFiles(outputFilename);




def writeTableEntryForOverview(dim,particles,ppc,dt,summaryHTMLFile):
  filename = "result_reduced-data_" + str(dim) + "_" + str(particles) + "_" + str(ppc) + "_" + str(dt) + "-1-6-log.png"
  summaryHTMLFile.write( "<td align=\"center\">" )
  summaryHTMLFile.write( "#particles=" + str(particles) + "<br />" )
  summaryHTMLFile.write( "ppc=" + str(ppc) + "<br />" )
  summaryHTMLFile.write( "dt=" + str(dt) + "<br />" )
  summaryHTMLFile.write( "<img src=\"" + filename + "\" />" )
  summaryHTMLFile.write( "</td>" )



#
#   Main
# ========
#
if len( sys.argv )!=2:
  print "please pass in name of test system (polaris, e.g.)"
  quit()

summaryHTMLFile = open("summary-" + sys.argv[1] + ".html", "w" )
summaryHTMLFile.write( "<h1>Summary " + sys.argv[1] + "</h1>" )


for dim in Dimensions:
 summaryHTMLFile.write( "<h2>Overview, d=" + str(dim) + "</h2>" )
 summaryHTMLFile.write( "<table>" )

 for particles in Particles:
  for ppc in PPCs:
   summaryHTMLFile.write( "<tr>" )
   for dt in DTs:
    writeTableEntryForOverview(dim,particles,ppc,dt,summaryHTMLFile)
   summaryHTMLFile.write( "</tr>" )
    
 summaryHTMLFile.write( "</table>" )

summaryHTMLFile.write( "<h2>Detailed results</h2>" )


for dim in Dimensions:
 for dt in DTs:
  for ppc in PPCs:
   for particles in Particles:
     plotAllResults( particles, ppc, dt, dim )
     