import re
import pylab


def toString(name):
  if name=="pit":
    return "PIT"
  if name=="pidt":
    return "PIDT"
  if name=="rapidt":
    return "raPIDT"
  if name=="supermuc":
    return "SuperMUC"
  if name=="polaris":
    return "Polaris"
  return name
  

def setGeneralPlotSettings():
  pylab.grid(True)
  pylab.rcParams.update({'font.size': 18})
  try:
    pylab.legend(framealpha=0.5)
    #pylab.legend(fontsize=14, framealpha=0.5)
  except:
    # old pylab version
    l = pylab.legend(prop={'size':9})
    l.get_frame().set_alpha(0.5)
    
    
    
    
def isSearchedStatisticsLine(data, isPit):
  if ( isPit ):
    return re.search( "MoveParticles", data ) and re.search( "logIterationStatistics",data);
  else:
    return re.search( "MoveParticlesWithManuallyMergedParticleHandling", data ) and re.search( "logIterationStatistics",data);



def getRuntime(filename,isPit):
  try:
    file = open(filename, "r" )
  except:
    print( "was not able to open file " + filename )
    return -1.0
  try:
    data = "   "
    while ( not data=="" and not re.search( "grid initialisation done", data ) ):
      data = file.readline()
    startTimeStamp = float( data.strip().split( " " )[0] )
    while ( not data=="" and not re.search( "logIterationStatistics", data ) ):
      data = file.readline()
    endTimeStamp = float( data.strip().split( " " )[0] )
    return endTimeStamp - startTimeStamp
  except:
    print( "was not able to parse file " + filename + " and evaluate runtime")
    return -1.0


def readColumnFromTable(filename,whichColumn):
  result = [] 
  try:
    file = open(filename, "r" )
  except:
    print( "was not able to open file " + filename )
    return -1.0
  try:
    file.readline()
    for line in file:
      #if ( not re.search( "hline", line ) and ):
      #  print "got " + line
      try:
        data = float( line.split( "&" )[whichColumn] )
        result.append( data )
      except:
        result.append( 0.0 )
    return result
  except:
    print( "was not able to parse file " + filename + " holding a table ")
    return []


def computeAverageColumn(columns):
  result = [] 
  for row in range(0,len(columns[0])):
    result.append( 0.0 )
  for col in range(0,len(columns)):
    for row in range(0,len(columns[col])):
      result[row] = result[row] + columns[col][row]
  for row in range(0,len(columns[0])):
    result[row] = result[row]/len(columns)
  return result
  

def getParticles(filename,isPit):
  try:
    file = open(filename, "r" )
  except:
    print( "was not able to open file " + filename )
    return -1
  try: 
    data = "   "
    while ( not data=="" and not re.search( "#particles", data )):
      data = file.readline()
    if ( not data=="" ):
      data = data.split("=")[1]
      data = data.split("(")[0]
      data = data.split(",")[0]
      return float(data.strip())
    else:
      return -1
  except:
    print( "was not able to parse file " + filename + " and search for #particles substring")
    return -1


def getIterations(filename,isPit):
  try:
    file = open(filename, "r" )
  except:
    print( "was not able to open file " + filename )
    return -1
  try:
    data = "   "
    while ( not data=="" and not isSearchedStatisticsLine(data,isPit) ):
        data = file.readline()
    if ( not data=="" ):
      return int(data.split("|")[2].split("|")[0].strip())
    else:
      return -1
  except:
    print( "was not able to parse file " + filename + " and search for MoveParticles substring")
    return -1

#
# Read out a likwid field
#
# @param metric  String such as "MFlops/s" or "L2 miss rate"
# @param column  Which column to read.
# 
# !!! Column
#
# If you are in the serial mode, you should pass 0 for column. The script then 
# reads out the second column (the first one holds the labels). If you are in a 
# multithreaded mode, you typically pass not a pure metric label but one that 
# is augmented with "STAT" as you don't want to read out the individual 
# counters of the cores but rather the summaries. In this case, different values
# for column make sense:
#    - 0 gives you the sum of the counters,
#    - 1 the max,
#    - 2 the min, and    
#    - 3 the average
#   
# These values stem from the Likwid output. They are not defined by me.
#
def getLikwidField(filename,metric,column):
  result = 0
  #print( "read file " + filename )
  try:
    file = open(filename, "r" )
    data = "   "
    while ( not data=="" and not re.search( metric, data )):
        data = file.readline()
    if ( not data=="" ):
      result = float(data.split("|")[2+column].split("|")[0].strip())
  except:
    print( "was not able to open or read file " + filename )
  finally:
    return result
    
    
def compactData(xData,yData):
  resultXData = []
  resultYData = []
  
  try:
    for i in range(0,len(xData)):
      if yData[i]>0:
        resultXData.append( xData[i] )
        resultYData.append( yData[i] )
  except:
    return ([],[])
  return (resultXData,resultYData)


    