#
# argument is the prefix such as supermuc
#
#
import sys
import os
import pylab

from helpers import *


dts        = [ "0.01", "0.0001", "0.000001" ]
machines   = [ "polaris", "supermuc" ]
labels     = [
  "PIT,  $(0.0,1.0)^2$", "PIT,  $(0.0,0.1)^2$", 
  "PIDT, $(0.0,1.0)^2$", "PIDT, $(0.0,0.1)^2$", 
  "PIT,  $(0.0,1.0)^2$", "PIT,  $(0.0,0.1)^3$", 
  "PIDT, $(0.0,1.0)^2$", "PIDT, $(0.0,0.1)^3$"
] 
 

summaryHTMLFile = open("summary.html", "w" )


ppcs     = [ 1e7, 1e6, 1e5, 1e4, 1e3, 1e2, 1e1 ]

for dt in dts:
  for machine in machines:
    outputFileName = "single-core-throughput-dt-" + dt.replace( ".", "_" ) + "-" + machine
    inputFileName  = "single-core-throughput-dt-" + dt + "-" + machine + ".table"
    print "create " + outputFileName + " from " + inputFileName
    
    pit_1_0  = readColumnFromTable( inputFileName, 1 )
    pit_0_1  = readColumnFromTable( inputFileName, 3 )
    pidt_1_0 = readColumnFromTable( inputFileName, 5 )
    pidt_0_1 = readColumnFromTable( inputFileName, 7 )

    pylab.clf()
    pylab.title( toString(machine) + ", $\Delta t$=" + dt )
    pylab.xlabel('ppc')
    pylab.ylabel('#particles/s')
    pylab.xscale('log')
    pylab.yscale('log')
    pylab.ylim([10000,1e8])

    pylab.plot(ppcs, pit_1_0[1:8],     '-o',  label=labels[0],  color='#000000', markersize=10 )
    pylab.plot(ppcs, pit_0_1[1:8],     '--o', label=labels[1],  color='#ff0000', markersize=10 )
    pylab.plot(ppcs, pidt_1_0[1:8],    '-v',  label=labels[2],  color='#00ff00', markersize=10 )
    pylab.plot(ppcs, pidt_0_1[1:8],    '--v', label=labels[3],  color='#0000ff', markersize=10 )
    pylab.plot(ppcs, pit_1_0[8+1:-1],  '-^',  label=labels[4],  color='#000000', markersize=10 )
    pylab.plot(ppcs, pit_0_1[8+1:-1],  '--^', label=labels[5],  color='#bb0000', markersize=10 )
    pylab.plot(ppcs, pidt_1_0[8+1:-1], '-x',  label=labels[6],  color='#00bb00', markersize=10 )
    pylab.plot(ppcs, pidt_0_1[8+1:-1], '--x', label=labels[7],  color='#0000bb', markersize=10 )
  
    setGeneralPlotSettings()
	
    pylab.savefig( outputFileName + ".png" )
    pylab.savefig( outputFileName + ".pdf" )
    pylab.savefig( outputFileName + ".eps" )      
    summaryHTMLFile.write( "<img src=\"" +  outputFileName + ".png\" /> <br />" ) 
	
	
filenames = [
  "pit_1_0",  
  "pit_0_1", 
  "pidt_1_0",  
  "pidt_0_1"
] 
	
labels     = [
  "PIT,  $(0.0,1.0)^d$", 
  "PIT,  $(0.0,0.1)^d$", 
  "PIDT,  $(0.0,1.0)^d$", 
  "PIDT,  $(0.0,0.1)^d$" 
] 	      
for machine in machines:
    for currentSetup in range(0,4):
      outputFileName = "single-core-throughput-" + filenames[currentSetup] + "-" + machine
      print "create " + outputFileName
      
      pylab.clf()
      pylab.xlabel('ppc')
      pylab.ylabel('#particles/s')
      pylab.xscale('log')
      pylab.yscale('log')
      pylab.ylim([10000,1e8])
      pylab.title( labels[currentSetup] )
    
      dt=dts[0]
      inputFileName  = "single-core-throughput-dt-" + dt + "-" + machine + ".table"
      data2d         = readColumnFromTable( inputFileName, 1+currentSetup*2 )[1:8]
      data3d         = readColumnFromTable( inputFileName, 1+currentSetup*2 )[8+1:-1]
      if (currentSetup==0):
        pylab.plot(ppcs, data2d, '-o',  label="$\Delta t$=" + "%.1e" %float(dt) +", d=2",  color='#0000ff', markersize=10 )
        pylab.plot(ppcs, data3d, '--o', label="$\Delta t$=" + "%.1e" %float(dt) +", d=3",  color='#0000bb', markersize=10 )
      else:
        pylab.plot(ppcs, data2d, '-o',  color='#0000ff', markersize=10 )
        pylab.plot(ppcs, data3d, '--o', color='#0000bb', markersize=10 )
      
      dt=dts[1]
      inputFileName  = "single-core-throughput-dt-" + dt + "-" + machine + ".table"
      data2d         = readColumnFromTable( inputFileName, 1+currentSetup*2 )[1:8]
      data3d         = readColumnFromTable( inputFileName, 1+currentSetup*2 )[8+1:-1]
      if (currentSetup==3):
        pylab.plot(ppcs, data2d, '-^', label="$\Delta t$=" + "%.1e" %float(dt) +", d=2",  color='#00ff00', markersize=10 )
        pylab.plot(ppcs, data3d, '--^', label="$\Delta t$=" + "%.1e" %float(dt) +", d=3",  color='#00bb00', markersize=10 )
      else:
        pylab.plot(ppcs, data2d, '-^',  color='#00ff00', markersize=10 )
        pylab.plot(ppcs, data3d, '--^', color='#00bb00', markersize=10 )
      
      dt=dts[2]
      inputFileName  = "single-core-throughput-dt-" + dt + "-" + machine + ".table"
      data2d         = readColumnFromTable( inputFileName, 1+currentSetup*2 )[1:8]
      data3d         = readColumnFromTable( inputFileName, 1+currentSetup*2 )[8+1:-1]
      if (currentSetup==2):
        pylab.plot(ppcs, data2d, '-s', label="$\Delta t$=" + "%.1e" %float(dt) +", d=2",  color='#ff0000', markersize=10 )
        pylab.plot(ppcs, data3d, '--s', label="$\Delta t$=" + "%.1e" %float(dt) +", d=3",  color='#bb0000', markersize=10 )
      else:
        pylab.plot(ppcs, data2d, '-s',  color='#ff0000', markersize=10 )
        pylab.plot(ppcs, data3d, '--s', color='#bb0000', markersize=10 )
      
      setGeneralPlotSettings()   
      pylab.legend(loc="lower left",framealpha=0.5) 
      
      #if (currentSetup>1):
      #  #pylab.legend(show=False)
      #  pylab.legend().set_visible(False)
      
      pylab.savefig( outputFileName + ".png" )
      pylab.savefig( outputFileName + ".pdf" )
      pylab.savefig( outputFileName + ".eps" )      
      summaryHTMLFile.write( "<img src=\"" +  outputFileName + ".png\" /> <br />" ) 

